summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--lib/ZVariables.c2
-rw-r--r--lib/acl_files.c9
2 files changed, 6 insertions, 5 deletions
diff --git a/lib/ZVariables.c b/lib/ZVariables.c
index ffa918d..e006ac6 100644
--- a/lib/ZVariables.c
+++ b/lib/ZVariables.c
@@ -184,7 +184,7 @@ static int varline(bfr, var)
return(0); /* var is not the var in
bfr ==> no match */
- cp = index(bfr, '=');
+ cp = strchr(bfr, '=');
if (!cp)
return(0);
cp++;
diff --git a/lib/acl_files.c b/lib/acl_files.c
index 948a668..c259957 100644
--- a/lib/acl_files.c
+++ b/lib/acl_files.c
@@ -28,6 +28,7 @@ static char rcsid_acl_files_c[] = "$Id$";
#include <zephyr/zephyr.h>
#include <strings.h>
#include <sys/file.h>
+#include <fcntl.h>
#include <sys/stat.h>
#include <ctype.h>
#include <sys/param.h> /* for MAXHOSTNAMELEN */
@@ -68,8 +69,8 @@ char *canon;
char *dot, *atsign, *end;
int len;
- dot = index(principal, INST_SEP);
- atsign = index(principal, REALM_SEP);
+ dot = strchr(principal, INST_SEP);
+ atsign = strchr(principal, REALM_SEP);
/* Maybe we're done already */
if(dot != NULL && atsign != NULL) {
@@ -477,8 +478,8 @@ char *principal;
return 1;
/* Try the wildcards */
- realm = index(canon, REALM_SEP);
- *index(canon, INST_SEP) = '\0'; /* Chuck the instance */
+ realm = strchr(canon, REALM_SEP);
+ *strchr(canon, INST_SEP) = '\0'; /* Chuck the instance */
sprintf(buf, "%s.*%s", canon, realm);
if(acl_exact_match(acl, buf)) return 1;